@@ -24,9 +24,10 @@ describe 'nova::logging' do
      :instance_uuid_format => '[instance: %(uuid)s] ',
      :log_date_format => '%Y-%m-%d %H:%M:%S',
      :use_syslog => true,
+     :use_json => true,
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
-     :log_dir => '/var/log/foo',
+     :log_dir => '/var/log',
      :debug => true,
     }
   end
@@ -57,17 +58,11 @@ describe 'nova::logging' do
     it 'configures nova logging settings with default values' do
       is_expected.to contain_oslo__log('nova_config').with(
         :use_syslog => '<SERVICE DEFAULT>',
+        :use_json   => '<SERVICE DEFAULT>',
         :use_stderr => '<SERVICE DEFAULT>',
         :log_dir    => '/var/log/nova',
         :debug      => '<SERVICE DEFAULT>',
       )
-      is_expected.to contain_file('/var/log/nova').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_file('/var/log/nova/nova-manage.log').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_exec('chown nova logfiles')
     end
   end
 
@@ -75,18 +70,12 @@ describe 'nova::logging' do
     it 'configures nova logging settings with non-default values' do
       is_expected.to contain_oslo__log('nova_config').with(
         :use_syslog          => true,
+        :use_json            => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
-        :log_dir             => '/var/log/foo',
+        :log_dir             => '/var/log',
         :debug               => true,
       )
-      is_expected.to contain_file('/var/log/foo').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_file('/var/log/foo/nova-manage.log').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_exec('chown nova logfiles')
     end
   end
 
@@ -109,13 +98,6 @@ describe 'nova::logging' do
        :instance_uuid_format           => '[instance: %(uuid)s] ',
        :log_date_format                => '%Y-%m-%d %H:%M:%S',
       )
-      is_expected.to contain_file('/var/log/foo').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_file('/var/log/foo/nova-manage.log').with(
-        :owner        => 'nova',
-      )
-      is_expected.to contain_exec('chown nova logfiles')
     end
   end
 
